@@ -72,7 +72,7 @@ setMethod("addFeatures",signature="CuffData",.addFeatures)
 #Accessors
 ###################
 .annotation<-function(object){
-	featureQuery<-paste("SELECT * FROM ",object@tables$mainTable," x LEFT JOIN ",object@tables$featureTable," xf USING (",object@idField,")",sep="")
+	featureQuery<-paste("SELECT * FROM ",object@tables$mainTable," x LEFT JOIN features xf USING (",object@idField,")",sep="")
 	dbGetQuery(object@DB, featureQuery)
 }
 
@@ -124,7 +124,7 @@ setMethod("replicates","CuffData",.replicates)
 	if(!features){
 		FPKMQuery<-paste("SELECT * FROM ",object@tables$dataTable," WHERE sample_name IN ",sampleString,sep="")
 	}else{
-		FPKMQuery<-paste("SELECT xf.*,xm.*,x.sample_name,x.fpkm,x.conf_hi,x.conf_lo FROM ",object@tables$dataTable," x LEFT JOIN ",object@tables$featureTable," xf ON x.",object@idField,"=xf.",object@idField," LEFT JOIN ",object@tables$mainTable," xm ON x.",object@idField,"=xm.",object@idField," WHERE x.sample_name IN ",sampleString,sep="")
+		FPKMQuery<-paste("SELECT xf.*,xm.*,x.sample_name,x.fpkm,x.conf_hi,x.conf_lo FROM ",object@tables$dataTable," x LEFT JOIN features xf ON x.",object@idField,"=xf.",object@idField," LEFT JOIN ",object@tables$mainTable," xm ON x.",object@idField,"=xm.",object@idField," WHERE x.sample_name IN ",sampleString,sep="")
 		#print(FPKMQuery)
 	}
 	res<-dbGetQuery(object@DB,FPKMQuery)
@@ -157,7 +157,7 @@ setMethod("fpkm","CuffData",.fpkm)
 	if(!features){
 		FPKMQuery<-paste("SELECT * FROM ",object@tables$replicateTable," WHERE rep_name IN ",sampleString,sep="")
 	}else{
-		FPKMQuery<-paste("SELECT xf.*,xm.*,x.rep_name,x.raw_frags,x.internal_scaled_frags,x.external_scaled_frags,x.fpkm,x.effective_length,x.status FROM ",object@tables$replicateTable," x LEFT JOIN ",object@tables$featureTable," xf on x.",object@idField,"=xf.",object@idField," LEFT JOIN ",object@tables$mainTable," xm ON x.",object@idField,"=xm.",object@idField," WHERE x.rep_name IN ",sampleString,sep="")
+		FPKMQuery<-paste("SELECT xf.*,xm.*,x.rep_name,x.raw_frags,x.internal_scaled_frags,x.external_scaled_frags,x.fpkm,x.effective_length,x.status FROM ",object@tables$replicateTable," x LEFT JOIN features xf on x.",object@idField,"=xf.",object@idField," LEFT JOIN ",object@tables$mainTable," xm ON x.",object@idField,"=xm.",object@idField," WHERE x.rep_name IN ",sampleString,sep="")
 	}
 	#print(FPKMQuery)
 	res<-dbGetQuery(object@DB,FPKMQuery)
@@ -211,14 +211,19 @@ setMethod("count","CuffData",.count)
 	}
 	
 	samp<-samples(object)
-	FPKMMatQuery<-paste("select x.",object@idField,", ",sep="")
+	FPKMMatQuery<-paste("select x.",object@idField,", x.gene_short_name, ",sep="")
 	for (i in samp){
 		FPKMMatQuery<-paste(FPKMMatQuery,"sum(case when xd.sample_name ='",i,"' then fpkm end) as ",i,",",sep="")
 	}
 	FPKMMatQuery<-substr(FPKMMatQuery, 1, nchar(FPKMMatQuery)-1)
 	FPKMMatQuery<-paste(FPKMMatQuery," from ",object@tables$mainTable," x LEFT JOIN ",object@tables$dataTable," xd on x.",object@idField," = xd.",object@idField," group by x.",object@idField,sep="")
 	res<-dbGetQuery(object@DB,FPKMMatQuery)
-	res<-data.frame(res[,-1],row.names=res[,1])
+	if(fullnames){
+		res<-data.frame(res[,-c(1,2)],row.names=paste(res[,2],res[,1],sep="|"))
+	}else{
+		res<-data.frame(res[,-c(1,2)],row.names=res[,1])	
+	}
+	
 	if(!missing(sampleIdList)){
 		res<-data.frame(res[,sampleIdList],row.names=rownames(res))
 		colnames(res)<-sampleIdList
@@ -241,14 +246,19 @@ setMethod("fpkmMatrix","CuffData",.fpkmMatrix)
 	}
 	
 	samp<-replicates(object)
-	FPKMMatQuery<-paste("select x.",object@idField,", ",sep="")
+	FPKMMatQuery<-paste("select x.",object@idField,", x.gene_short_name, ",sep="")
 	for (i in samp){
 		FPKMMatQuery<-paste(FPKMMatQuery,"sum(case when xd.rep_name ='",i,"' then fpkm end) as ",i,",",sep="")
 	}
 	FPKMMatQuery<-substr(FPKMMatQuery, 1, nchar(FPKMMatQuery)-1)
 	FPKMMatQuery<-paste(FPKMMatQuery," from ",object@tables$mainTable," x LEFT JOIN ",object@tables$replicateTable," xd on x.",object@idField," = xd.",object@idField," group by x.",object@idField,sep="")
 	res<-dbGetQuery(object@DB,FPKMMatQuery)
-	res<-data.frame(res[,-1],row.names=res[,1])
+
+	if(fullnames){
+		res<-data.frame(res[,-c(1,2)],row.names=paste(res[,2],res[,1],sep="|"))
+	}else{
+		res<-data.frame(res[,-c(1,2)],row.names=res[,1])	
+	}
 	if(!missing(repIdList)){
 		res<-data.frame(res[,repIdList],row.names=rownames(res))
 		colnames(res)<-repIdList
@@ -271,14 +281,18 @@ setMethod("repFpkmMatrix","CuffData",.repFpkmMatrix)
 	}
 	
 	samp<-samples(object)
-	CountMatQuery<-paste("select x.",object@idField,", ",sep="")
+	CountMatQuery<-paste("select x.",object@idField,", x.gene_short_name, ",sep="")
 	for (i in samp){
 		CountMatQuery<-paste(CountMatQuery,"sum(case when xd.sample_name ='",i,"' then count end) as ",i,",",sep="")
 	}
 	CountMatQuery<-substr(CountMatQuery, 1, nchar(CountMatQuery)-1)
 	CountMatQuery<-paste(CountMatQuery," from ",object@tables$mainTable," x LEFT JOIN ",object@tables$countTable," xd on x.",object@idField," = xd.",object@idField," group by x.",object@idField,sep="")
 	res<-dbGetQuery(object@DB,CountMatQuery)
-	res<-data.frame(res[,-1],row.names=res[,1])
+	if(fullnames){
+		res<-data.frame(res[,-c(1,2)],row.names=paste(res[,2],res[,1],sep="|"))
+	}else{
+		res<-data.frame(res[,-c(1,2)],row.names=res[,1])	
+	}
 	if(!missing(sampleIdList)){
 		res<-data.frame(res[,sampleIdList],row.names=rownames(res))
 		colnames(res)<-sampleIdList
@@ -300,14 +314,18 @@ setMethod("countMatrix","CuffData",.countMatrix)
 		myLevels<-getRepLevels(object)
 	}
 	reps<-replicates(object)
-	repCountMatQuery<-paste("select x.",object@idField,", ",sep="")
+	repCountMatQuery<-paste("select x.",object@idField,", x.gene_short_name, ",sep="")
 	for (i in reps){
 		repCountMatQuery<-paste(repCountMatQuery,"sum(case when xr.rep_name ='",i,"' then external_scaled_frags end) as ",i,",",sep="")
 	}
 	repCountMatQuery<-substr(repCountMatQuery, 1, nchar(repCountMatQuery)-1)
 	repCountMatQuery<-paste(repCountMatQuery," from ",object@tables$mainTable," x LEFT JOIN ",object@tables$replicateTable," xr on x.",object@idField," = xr.",object@idField," group by x.",object@idField,sep="")
 	res<-dbGetQuery(object@DB,repCountMatQuery)
-	res<-data.frame(res[,-1],row.names=res[,1])
+	if(fullnames){
+		res<-data.frame(res[,-c(1,2)],row.names=paste(res[,2],res[,1],sep="|"))
+	}else{
+		res<-data.frame(res[,-c(1,2)],row.names=res[,1])	
+	}
 	if(!missing(repIdList)){
 		res<-data.frame(res[,repIdList],row.names=rownames(res))
 		colnames(res)<-repIdList
@@ -331,7 +349,7 @@ setMethod("repCountMatrix","CuffData",.repCountMatrix)
 		if(!features){
 			diffQuery<-paste("SELECT * FROM ",object@tables$expDiffTable,sep="")
 		}else{
-			diffQuery<-paste("SELECT xm.*, xed.*, xf.* FROM ",object@tables$mainTable," xm LEFT JOIN ",object@tables$expDiffTable," xed ON xm.",object@idField,"=xed.",object@idField," LEFT JOIN ",object@tables$featureTable," xf ON xm.",object@idField,"=xf.",object@idField,sep="")
+			diffQuery<-paste("SELECT xm.*, xed.*, xf.* FROM ",object@tables$mainTable," xm LEFT JOIN ",object@tables$expDiffTable," xed ON xm.",object@idField,"=xed.",object@idField," LEFT JOIN features xf ON xm.",object@idField,"=xf.",object@idField,sep="")
 		}
 	}else if (missing(x) || missing(y)){
 		stop("You must supply both x and y or neither.")
@@ -339,7 +357,7 @@ setMethod("repCountMatrix","CuffData",.repCountMatrix)
 		if(!features){
 			diffQuery<-paste("SELECT x.",object@idField,", xed.* FROM ",object@tables$mainTable," x LEFT JOIN ",object@tables$expDiffTable," xed on x.",object@idField," = xed.",object@idField," WHERE ((sample_1 = '",x,"' AND sample_2 = '",y,"') OR (sample_1 = '",y,"' AND sample_2 = '",x,"'))",sep="")
 		}else{
-			diffQuery<-paste("SELECT xm.*, xed.*, xf.* FROM ",object@tables$mainTable," xm LEFT JOIN ",object@tables$expDiffTable," xed on xm.",object@idField," = xed.",object@idField," LEFT JOIN ",object@tables$featureTable," xf ON xm.",object@idField,"=xf.",object@idField," WHERE ((sample_1 = '",x,"' AND sample_2 = '",y,"') OR (sample_1 = '",y,"' AND sample_2 = '",x,"'))",sep="")
+			diffQuery<-paste("SELECT xm.*, xed.*, xf.* FROM ",object@tables$mainTable," xm LEFT JOIN ",object@tables$expDiffTable," xed on xm.",object@idField," = xed.",object@idField," LEFT JOIN features xf ON xm.",object@idField,"=xf.",object@idField," WHERE ((sample_1 = '",x,"' AND sample_2 = '",y,"') OR (sample_1 = '",y,"' AND sample_2 = '",x,"'))",sep="")
 		}
 	}
 	dat<-dbGetQuery(object@DB,diffQuery)
@@ -459,6 +477,12 @@ setMethod("getLevels",signature(object="CuffData"),.getLevels)
 
 setMethod("getRepLevels",signature(object="CuffData"),.getRepLevels)
 
+.getRepConditionLevels<-function(object){
+	levelsQuery<-'SELECT r.sample_name FROM replicates r JOIN samples s ON r.sample_name=s.sample_name ORDER BY s.sample_index ASC'
+	levels<-dbGetQuery(object@DB,levelsQuery)$sample_name
+	levels
+}
+
 #Useful SQL commands
 
 #SELECT g.gene_id, g.class_code, g.nearest_ref_id, g.gene_short_name, g.locus, g.length, g.coverage, g.status, gd.sample_name, gd.fpkm, gd.conf_hi, gd.conf_lo FROM genes g LEFT JOIN geneData gd ON g.gene_id = gd.gene_id WHERE (g.gene_id = 'XLOC_000001');
@@ -505,7 +529,7 @@ setMethod("getRepLevels",signature(object="CuffData"),.getRepLevels)
 setMethod("csDensity",signature(object="CuffData"),.density)
 
 .scatter<-function(object,x,y,logMode=TRUE,pseudocount=1.0,labels,smooth=FALSE,colorByStatus=FALSE, drawRug=TRUE, ...){
-	dat<-fpkmMatrix(object)
+	dat<-fpkmMatrix(object,fullnames=TRUE)
 	samp<-samples(object)
 	
 	#check to make sure x and y are in samples
@@ -520,6 +544,16 @@ setMethod("csDensity",signature(object="CuffData"),.density)
 		}
 	}
 	
+	#Attach tracking_id and gene_short_name
+	if(!missing(labels)){
+		require(stringr)
+		tracking<-str_split_fixed(rownames(dat),"\\|",2)
+		dat$gene_short_name<-tracking[,1]
+		dat$tracking_id<-tracking[,2]
+		
+		labeled.dat<-dat[dat$gene_short_name %in% labels,]
+	}
+	
 	#make plot object
 	p<-ggplot(dat)
 	p<- p + aes_string(x=x,y=y)
@@ -544,15 +578,11 @@ setMethod("csDensity",signature(object="CuffData"),.density)
 	}
 	
 	#Add highlights from labels
-#	if(!missing(labels)){
-#		labelIdx<-fData(object)$gene_short_name %in% labels
-#		labelfp<-fp[labelIdx,]
-#		labelfp$gene_short_name<-fData(object)$gene_short_name[labelIdx]
-#		#print(head(labelfp))
-#		p <- p + geom_point(data=labelfp,size=1.2,color="red")
-#		p <- p + geom_text(data=labelfp,aes(label=gene_short_name),color="red",hjust=0,vjust=0,angle=45,size=2)
-#	}
-#	
+	if(!missing(labels)){
+		p <- p + geom_point(data=labeled.dat,aes_string(x=x,y=y),size=1.3,color="red")
+		p <- p + geom_text(data=labeled.dat,aes_string(x=x,y=y,label='gene_short_name'),color="red",hjust=0,vjust=0,angle=0,size=4)
+	}
+	
 	#logMode
 	if(logMode){
 		p <- p + scale_y_log10() + scale_x_log10()
@@ -565,6 +595,80 @@ setMethod("csDensity",signature(object="CuffData"),.density)
 
 setMethod("csScatter",signature(object="CuffData"), .scatter)
 
+.scatter2<-function(object,x,y,logMode=TRUE,pseudocount=1.0,labels,smooth=FALSE,alpha=0.05,colorByStatus=FALSE, drawRug=TRUE, ...){
+	samp<-samples(object)
+	
+	#check to make sure x and y are in samples
+	if (!all(c(x,y) %in% samp)){
+		stop("One or more values of 'x' or 'y' are not valid sample names!")
+	}
+	
+	#Setup query string
+	sampleList<-paste("('",x,"','",y,"')",sep="")
+	
+	scatterQuery<-paste("SELECT m.gene_short_name,d.",object@idField,",sum(CASE WHEN d.sample_name='",x,"' THEN d.fpkm END) as x,sum(CASE WHEN d.sample_name='",y,"' THEN d.fpkm END) as y, edd.status, edd.p_value, edd.q_value FROM ",object@tables$mainTable," m LEFT JOIN ",object@tables$dataTable," d ON m.",object@idField,"=d.",object@idField," LEFT JOIN ",object@tables$expDiffTable," edd ON m.",object@idField," = edd.",object@idField," WHERE (edd.sample_1 in ",sampleList," AND (edd.sample_2 in ",sampleList,")) GROUP BY d.",object@idField,";",sep="")
+	#write(scatterQuery,stderr())
+	
+	#Retrieve data
+	dat<-dbGetQuery(object@DB,scatterQuery)
+	
+	#add pseudocount if necessary
+	if(logMode){
+		for (i in samp){
+			dat$x<-dat$x+pseudocount
+			dat$y<-dat$y+pseudocount
+		}
+	}
+	
+	#Flag significant genes
+	dat$significant<-"no"
+	dat$significant[dat$q_value<=alpha]<-"yes"
+	dat$significant<-factor(dat$significant,levels=c("no","yes"))
+	
+	#Attach tracking_id and gene_short_name
+	if(!missing(labels)){
+		labeled.dat<-dat[dat$gene_short_name %in% labels,]
+	}
+	
+	#make plot object
+	p<-ggplot(dat) + theme_bw()
+	p<- p + aes_string(x='x',y='y')
+	
+	#Right now, this does nothing, because 'significant' is not returned from fpkmMatrix object so I don't have this as a feature to draw
+	if(colorByStatus){
+		p<- p + geom_point(aes(color=significant),size=1.2) + scale_color_manual(values=c("black","red"))
+	}else{
+		p<- p + geom_point(size=1.2,alpha=I(1/3))
+	}
+	#Add symmetry line
+	p<- p + geom_abline(intercept=0,slope=1,linetype=2) 
+	
+	#Add rug
+	if(drawRug){
+		p<- p + geom_rug(size=0.8,alpha=0.01)
+	}
+	
+	#add smoother
+	if(smooth){
+		p <- p + stat_smooth(method="lm",fill="blue",alpha=0.2)
+	}
+	
+	#Add highlights from labels
+	if(!missing(labels)){
+		p <- p + geom_point(data=labeled.dat,aes_string(x='x',y='y'),size=1.3,color="red")
+		p <- p + geom_text(data=labeled.dat,aes_string(x='x',y='y',label='gene_short_name'),color="red",hjust=0,vjust=0,angle=0,size=4)
+	}
+	
+	#logMode
+	if(logMode){
+		p <- p + scale_y_log10() + scale_x_log10()
+	}
+	
+	#Add title & Return value
+	p<- p + labs(title=object@tables$mainTable,x=x,y=y)
+	p
+}
+
 .scatterMat<-function(object,replicates=FALSE,logMode=TRUE,pseudocount=1.0,hexbin=FALSE,useCounts=FALSE,...){
 	if(replicates){
 		if(useCounts){
@@ -579,8 +683,9 @@ setMethod("csScatter",signature(object="CuffData"), .scatter)
 			dat<-fpkmMatrix(object)
 		}
 	}
-	
-	if(hexbin){
+
+	if(logMode)
+	{
 		dat<-dat+pseudocount
 	}
 	
@@ -627,12 +732,13 @@ setMethod("csScatterMatrix",signature(object="CuffData"),.scatterMat)
 	s2<-unique(dat$sample_2)
 	
 	p<-ggplot(dat)
-	if(showSignificant){
-		p<- p + geom_point(aes(x=log2_fold_change,y=-log10(p_value),color=significant),size=0.8)
-	}else{
+	if(showSignificant==FALSE){
 		p<- p + geom_point(aes(x=log2_fold_change,y=-log10(p_value)),size=1.2)
+	}else{
+		p<- p + geom_point(aes(x=log2_fold_change,y=-log10(p_value),color=significant),size=1.2)
 	}
 	#Add title and return
+	p<- p + theme_bw()
 	p<- p + labs(title=paste(object@tables$mainTable,": ",s2,"/",s1,sep=""))
 	p<- p + scale_colour_manual(values = c("black","red"))
 	
@@ -642,6 +748,7 @@ setMethod("csScatterMatrix",signature(object="CuffData"),.scatterMat)
 	p <- p + xlab(bquote(paste(log[2],"(fold change)",sep=""))) + 
 	    ylab(bquote(paste(-log[10],"(p value)",sep="")))
 	p
+	
 }
 
 setMethod("csVolcano",signature(object="CuffData"), .volcano)
@@ -667,7 +774,7 @@ setMethod("csVolcano",signature(object="CuffData"), .volcano)
 	mapping <- defaults(mapping, aes_string(x = "log2_fold_change", y = "-log10(p_value)", color="significant"))
 	class(mapping) <- "uneval"
 	
-	p <-ggplot(dat) + geom_point(mapping,na.rm=TRUE,size=0.8) + scale_colour_manual(values = c("black","red")) + geom_text(aes(x=0,y=15,label=label),data=filler) + facet_grid(sample_1~sample_2)
+	p <-ggplot(dat) + geom_point(mapping,na.rm=TRUE,size=0.8) + scale_colour_manual(values = c("black","red")) + facet_grid(sample_1~sample_2)
 	
 	p<- p + geom_vline(aes(x=0),linetype=2)
 	
@@ -679,7 +786,7 @@ setMethod("csVolcano",signature(object="CuffData"), .volcano)
 
 setMethod("csVolcanoMatrix",signature(object="CuffData"),.volcanoMatrix)
 
-.distheat<-function(object, replicates=F, samples.not.genes=T, logMode=T, pseudocount=1.0, heatscale=c(low='lightyellow',mid='orange',high='darkred'), heatMidpoint=NULL, ...) {
+.distheat<-function(object, replicates=F, samples.not.genes=T, logMode=T, pseudocount=1.0, heatscale=c(low='lightyellow',mid='orange',high='darkred'), heatMidpoint=NULL, sigDigits=3, ...) {
 	# get expression from a sample or gene perspective
 	if(replicates){
 		obj.fpkm<-repFpkmMatrix(object,fullnames=T)
@@ -706,7 +813,7 @@ setMethod("csVolcanoMatrix",signature(object="CuffData"),.volcanoMatrix)
 	
 	# make data frame
 	dist.df = melt(as.matrix(obj.dists),varnames=c("X1","X2"))
-	
+	dist.df$value<-as.numeric(format(dist.df$value,digits=sigDigits))
 	# initialize
 	g = ggplot(dist.df, aes(x=X1, y=X2, fill=value))
 	
@@ -731,7 +838,7 @@ setMethod("csVolcanoMatrix",signature(object="CuffData"),.volcanoMatrix)
 		g = g + scale_fill_gradient2(low=heatscale[1], mid=heatscale[2], high=heatscale[3], midpoint=heatMidpoint, name="JS Distance")
 	}
 	if(samples.not.genes){
-		g <- g + geom_text(aes(label=format(value,digits=3)))
+		g <- g + geom_text(aes(label=value))
 	}
 	# return
 	g
@@ -819,6 +926,7 @@ setMethod("dispersionPlot",signature(object="CuffData"),.dispersionPlot)
 .MDSplot<-function(object,replicates=FALSE,logMode=TRUE,pseudocount=1.0){
 	if(replicates){
 		dat<-repFpkmMatrix(object)
+		#repData<-sapply(replicates(object),function(x){strsplit(x,"_")[[1]][1]}) This is to color by condition and not replicate...
 	}else{
 		dat<-fpkmMatrix(object)
 	}
@@ -838,7 +946,7 @@ setMethod("dispersionPlot",signature(object="CuffData"),.dispersionPlot)
 setMethod("MDSplot",signature(object="CuffData"),.MDSplot)
 
 #Not sure if I want to include this or not..
-.PCAplot<-function(object,x="PC1", y="PC2",replicates=FALSE,pseudocount=1.0,scale=TRUE,...){
+.PCAplot<-function(object,x="PC1", y="PC2",replicates=FALSE,pseudocount=1.0,scale=TRUE,showPoints=TRUE,...){
 	if(replicates){
 		fpkms<-repFpkmMatrix(object)
 	}else{
@@ -849,7 +957,10 @@ setMethod("MDSplot",signature(object="CuffData"),.MDSplot)
 	dat <- data.frame(obsnames=row.names(PC$x), PC$x)
 	#dat$shoutout<-""
 	#dat$shoutout[matchpt(PC$rotation,PC$x)$index]<-rownames(pca$x[matchpt(pca$rotation,pca$x)$index,])
-	plot <- ggplot(dat, aes_string(x=x, y=y)) + geom_point(alpha=.4, size=0.8, aes(label=obsnames))
+	plot <- ggplot(dat, aes_string(x=x, y=y)) 
+	if(showPoints){
+		plot<- plot + geom_point(alpha=.4, size=0.8, aes(label=obsnames))
+	}
 	plot <- plot + geom_hline(aes(0), size=.2) + geom_vline(aes(0), size=.2) #+ geom_text(aes(label=shoutout),size=2,color="red")
 	datapc <- data.frame(varnames=rownames(PC$rotation), PC$rotation)
 	mult <- min(
@@ -862,8 +973,8 @@ setMethod("MDSplot",signature(object="CuffData"),.MDSplot)
 	)
 	plot <- plot + 
 			#coord_equal() + 
-			geom_text(data=datapc, aes(x=v1, y=v2, label=varnames), size = 3, vjust=1, color="red")
-	plot <- plot + geom_segment(data=datapc, aes(x=0, y=0, xend=v1, yend=v2), arrow=arrow(length=unit(0.2,"cm")), alpha=0.75, color="red") + theme_bw()
+			geom_text(data=datapc, aes(x=v1, y=v2, label=varnames,color=varnames), vjust=1)
+	plot <- plot + geom_segment(data=datapc, aes(x=0, y=0, xend=v1, yend=v2,color=varnames), arrow=arrow(length=unit(0.2,"cm")), alpha=0.75) + theme_bw()
 	plot
 }
 
@@ -893,15 +1004,27 @@ setMethod('PCAplot',signature(object="CuffData"),.PCAplot)
 	p
 }
 
-.fpkmSCVPlot<-function(object,FPKMLowerBound=1){
+.fpkmSCVPlot<-function(object,FPKMLowerBound=1,showPool=FALSE){
+	if(!showPool){
+		showPool=any(table(.getRepConditionLevels(object))<2) # Counts number of replicates per condition and requires a minimum of 2.  If any n<2, values are determined from pooling across samples.
+		if(showPool){
+			warning("At least one of your conditions does not have enough replicates to estimate variance. Estimating variance across all conditions instead.")
+		}
+	}
 	dat<-repFpkm(object)
 	colnames(dat)[1]<-"tracking_id"
 	dat<-dat[,c('tracking_id','sample_name','fpkm')]
 	dat<-dat[dat$fpkm>0,]
 	
+	if(showPool){
+		subsetCols<-c('tracking_id')
+	}else{
+		subsetCols<-c('tracking_id','sample_name')
+	}
+	
 	#Option 3 (tapply on log10(replicateFPKM) values)
-	dat.means<-tapply(dat$fpkm,dat[,c('tracking_id','sample_name')],function(x){mean(x,na.rm=T)})
-	dat.sd<-tapply(dat$fpkm,dat[,c('tracking_id','sample_name')],function(x){sd(x,na.rm=T)})
+	dat.means<-tapply(dat$fpkm,dat[,subsetCols],function(x){mean(x,na.rm=T)})
+	dat.sd<-tapply(dat$fpkm,dat[,subsetCols],function(x){sd(x,na.rm=T)})
 	#write("Calculating replicate fpkm mean...",stderr())
 	dat.means<-melt(dat.means)
 	#write("Calculating replicate fpkm stdev...",stderr())
@@ -912,16 +1035,22 @@ setMethod('PCAplot',signature(object="CuffData"),.PCAplot)
 	colnames(dat)[colnames(dat)=="dat.sd$stdev"]<-'stdev'
 	dat<-dat[!is.na(dat$stdev) & !is.na(dat$fpkm),]
 	dat<-dat[dat$fpkm>0 & dat$stdev>0,]
-	dat$sample_name<-factor(dat$sample_name,levels=samples(object))
+	if(!showPool){
+		dat$sample_name<-factor(dat$sample_name,levels=samples(object))
+	}
 	
 	p <-ggplot(dat,aes(x=fpkm,y=(stdev/fpkm)^2),na.rm=T)
 	#p <-ggplot(dat,aes(x=log10(fpkm+1),y=log10(stdev)),na.rm=T)
-	p <- p + #geom_point(aes(color=sample_name),size=1,na.rm=T) +
-		stat_smooth(aes(color=sample_name,fill=sample_name),na.rm=T,method='auto',fullrange=T) + 
-		scale_x_log10() +
-		scale_y_continuous(name=bquote(CV^2)) +
-		xlab(bquote(paste(log[10],"FPKM",sep=" "))) +
-		theme_bw() + xlim(c(log10(FPKMLowerBound),max(log10(dat$fpkm)))) + labs(title=object@type)
+	if(showPool){
+		p <- p + stat_smooth(na.rm=T,method='auto',fullrange=T)
+	}else{
+		p <- p + #geom_point(aes(color=sample_name),size=1,na.rm=T) +
+				stat_smooth(aes(color=sample_name,fill=sample_name),na.rm=T,method='auto',fullrange=T)
+	}
+	p <- p + scale_x_log10() +
+		 scale_y_continuous(name=bquote(CV^2)) +
+		 xlab(bquote(paste(log[10],"FPKM",sep=" "))) +
+		 theme_bw() + xlim(c(log10(FPKMLowerBound),max(log10(dat$fpkm)))) + labs(title=object@type)
 	p
 	
 }
@@ -964,6 +1093,31 @@ setMethod("fpkmSCVPlot",signature(object="CuffData"),.fpkmSCVPlot)
 
 setMethod("csSpecificity",signature(object="CuffData"),.specificity)
 
+######################
+# Exploratory Analysis
+######################
+
+.nmf<-function(object,k,logMode=T,pseudocount=1,maxiter=1000,replicates=FALSE,fullnames=FALSE){
+	require(NMFN)
+	if(missing(k)) stop("Please provide a rank value for factorization (arg=k)")
+	
+	if(replicates){
+		m=repFpkmMatrix(object,fullnames=fullnames)
+	}else{
+		m=fpkmMatrix(object,fullnames=fullnames)
+	}
+	
+	if(logMode) 
+	{
+		m = log10(m+pseudocount)
+	}
+	
+	myNMF<-nnmf(m,k=k,maxiter=maxiter)
+	return (myNMF)
+}
+
+setMethod("csNMF",signature(object="CuffData"),.nmf)
+
 #############
 # GSEA helper methods
 #############
@@ -989,7 +1143,50 @@ setMethod("csSpecificity",signature(object="CuffData"),.specificity)
 	#res
 }
 
-setMethod("makeRnk",signature(object="CuffData"),.makeRnk)
+.makeRnkTest<-function(object,x,y,filename,...){
+	samp<-samples(object)
+	#check to make sure x and y are in samples
+	if (!all(c(x,y) %in% samp)){
+		stop("One or more values of 'x' or 'y' are not valid sample names!")
+	}
+	query<-paste("SELECT gd.gene_id,g.gene_short_name,gd.test_stat FROM genes g LEFT JOIN geneExpDiffData gd ON g.gene_id=gd.gene_id WHERE ((gd.sample_1='",x,"' AND gd.sample_2='",y,"') OR (gd.sample_2='",x,"' AND gd.sample_1='",y,"')) ORDER BY gd.test_stat DESC",sep="")
+	#print(query)
+	res<-dbGetQuery(object@DB,query)
+	#Remove gene_id field
+	res<-res[,-1]
+	#Remove rows with "NA" for gene_short_name
+	res<-res[!is.na(res$gene_short_name),]
+	#Write to file
+	write.table(res,file=filename,sep="\t",quote=F,...,row.names=F,col.names=F)	
+}
+
+.makeRnkTestStat<-function(object,x,y,filename,...){
+	samp<-samples(object)
+	#check to make sure x and y are in samples
+	if (!all(c(x,y) %in% samp)){
+		stop("One or more values of 'x' or 'y' are not valid sample names!")
+	}
+	query<-paste("SELECT gd.gene_id,g.gene_short_name,gd.sample_1, gd.sample_2,gd.test_stat FROM genes g LEFT JOIN geneExpDiffData gd ON g.gene_id=gd.gene_id WHERE ((gd.sample_1 ='",x,"' AND gd.sample_2='",y,"') OR (gd.sample_2='",x,"' AND gd.sample_1='",y,"')) GROUP BY gd.gene_id",sep="")
+	res<-dbGetQuery(object@DB,query)
+	if(unique(res$sample_2)==x){
+		res2<-res
+		res2$test_stat<--(res$test_stat)
+		res2$sample_1<-res$sample_2
+		res2$sample_2<-res$sample_1
+		res<-res2
+	}
+	#Order by test_stat
+	res<-res[order(res$test_stat,decreasing=F),]
+	#Remove gene_id field
+	res<-res[,c('gene_short_name','test_stat')]
+	#Remove rows with "NA" for gene_short_name
+	res<-res[!is.na(res$gene_short_name),]
+	#Write to file
+	write.table(res,file=filename,sep="\t",quote=F,...,row.names=F,col.names=F)
+	#head(res)
+}
+
+setMethod("makeRnk",signature(object="CuffData"),.makeRnkTestStat)
 
 
 #############
