@@ -299,7 +299,16 @@ head(repFpkm(TSS(myGenes)))
 
 
 ###################################################
-### code chunk number 38: geneset_plots_1
+### code chunk number 38: create_geneset_3
+###################################################
+myGeneset.pluri<-getGenes(cuff,myGeneIds,sampleIdList=c("hESC","iPS"))
+
+myGeneset.pluri
+
+
+
+###################################################
+### code chunk number 39: geneset_plots_1
 ###################################################
 h<-csHeatmap(myGenes,cluster='both')
 h
@@ -308,7 +317,7 @@ h.rep
 
 
 ###################################################
-### code chunk number 39: geneset_plots_heatmap
+### code chunk number 40: geneset_plots_heatmap
 ###################################################
 h<-csHeatmap(myGenes,cluster='both')
 h
@@ -318,20 +327,20 @@ print(h)
 
 
 ###################################################
-### code chunk number 40: geneset_plots_heatmap_rep
+### code chunk number 41: geneset_plots_heatmap_rep
 ###################################################
 print(h.rep)
 
 
 ###################################################
-### code chunk number 41: geneset_plots_1.5
+### code chunk number 42: geneset_plots_1.5
 ###################################################
 b<-expressionBarplot(myGenes)
 b
 
 
 ###################################################
-### code chunk number 42: geneset_plots_barplot
+### code chunk number 43: geneset_plots_barplot
 ###################################################
 b<-expressionBarplot(myGenes)
 b
@@ -339,14 +348,14 @@ print(b)
 
 
 ###################################################
-### code chunk number 43: geneset_plots_2
+### code chunk number 44: geneset_plots_2
 ###################################################
 s<-csScatter(myGenes,"Fibroblasts","hESC",smooth=T)
 s
 
 
 ###################################################
-### code chunk number 44: geneset_plots_scatter
+### code chunk number 45: geneset_plots_scatter
 ###################################################
 s<-csScatter(myGenes,"Fibroblasts","hESC",smooth=T)
 s
@@ -354,14 +363,14 @@ print(s)
 
 
 ###################################################
-### code chunk number 45: geneset_plots_3
+### code chunk number 46: geneset_plots_3
 ###################################################
 v<-csVolcano(myGenes,"Fibroblasts","hESC")
 v
 
 
 ###################################################
-### code chunk number 46: geneset_plots_volcano
+### code chunk number 47: geneset_plots_volcano
 ###################################################
 v<-csVolcano(myGenes,"Fibroblasts","hESC")
 v
@@ -369,7 +378,7 @@ print(v)
 
 
 ###################################################
-### code chunk number 47: geneset_plots_4
+### code chunk number 48: geneset_plots_4
 ###################################################
 ih<-csHeatmap(isoforms(myGenes),cluster='both',labRow=F)
 ih
@@ -378,7 +387,7 @@ th
 
 
 ###################################################
-### code chunk number 48: geneset_plots_isoform_heatmap
+### code chunk number 49: geneset_plots_isoform_heatmap
 ###################################################
 ih<-csHeatmap(isoforms(myGenes),cluster='both',labRow=F)
 ih
@@ -388,26 +397,26 @@ print(ih)
 
 
 ###################################################
-### code chunk number 49: geneset_plots_TSS_heatmap
+### code chunk number 50: geneset_plots_TSS_heatmap
 ###################################################
 print(th)
 
 
 ###################################################
-### code chunk number 50: geneset_plots_5
+### code chunk number 51: geneset_plots_5
 ###################################################
 den<-csDendro(myGenes)
 
 
 ###################################################
-### code chunk number 51: geneset_plots_dendro
+### code chunk number 52: geneset_plots_dendro
 ###################################################
 den<-csDendro(myGenes)
 plot(den)
 
 
 ###################################################
-### code chunk number 52: gene_level_1
+### code chunk number 53: gene_level_1
 ###################################################
 myGeneId<-"PINK1"
 myGene<-getGene(cuff,myGeneId)
@@ -417,7 +426,7 @@ head(fpkm(isoforms(myGene)))
 
 
 ###################################################
-### code chunk number 53: gene_plots_1
+### code chunk number 54: gene_plots_1
 ###################################################
 gl<-expressionPlot(myGene)
 gl
@@ -433,7 +442,7 @@ gl.cds.rep
 
 
 ###################################################
-### code chunk number 54: gene_plots_line
+### code chunk number 55: gene_plots_line
 ###################################################
 gl<-expressionPlot(myGene)
 gl
@@ -450,28 +459,28 @@ gl.cds.rep
 
 
 ###################################################
-### code chunk number 55: gene_plots_replicate_line
+### code chunk number 56: gene_plots_replicate_line
 ###################################################
 
 	print(gl.rep)
 
 
 ###################################################
-### code chunk number 56: gene_plots_iso_replicate_line
+### code chunk number 57: gene_plots_iso_replicate_line
 ###################################################
 
 	print(gl.iso.rep)
 
 
 ###################################################
-### code chunk number 57: gene_plots_cds_replicate_line
+### code chunk number 58: gene_plots_cds_replicate_line
 ###################################################
 
 	print(gl.cds.rep)
 
 
 ###################################################
-### code chunk number 58: gene_plots_2
+### code chunk number 59: gene_plots_2
 ###################################################
 gb<-expressionBarplot(myGene)
 gb
@@ -480,7 +489,7 @@ gb.rep
 
 
 ###################################################
-### code chunk number 59: gene_plots_bar
+### code chunk number 60: gene_plots_bar
 ###################################################
 gb<-expressionBarplot(myGene)
 gb
@@ -490,20 +499,20 @@ print(gb)
 
 
 ###################################################
-### code chunk number 60: gene_plots_bar_rep
+### code chunk number 61: gene_plots_bar_rep
 ###################################################
 print(gb.rep)
 
 
 ###################################################
-### code chunk number 61: gene_plots_3
+### code chunk number 62: gene_plots_3
 ###################################################
 igb<-expressionBarplot(isoforms(myGene),replicates=T)
 igb
 
 
 ###################################################
-### code chunk number 62: gene_plots_bar_isoforms
+### code chunk number 63: gene_plots_bar_isoforms
 ###################################################
 igb<-expressionBarplot(isoforms(myGene),replicates=T)
 igb
@@ -511,20 +520,35 @@ print(igb)
 
 
 ###################################################
-### code chunk number 63: features_1
+### code chunk number 64: gene_plots_4
+###################################################
+gp<-csPie(myGene,level="isoforms")
+gp
+
+
+###################################################
+### code chunk number 65: gene_plots_pie
+###################################################
+gp<-csPie(myGene,level="isoforms")
+gp
+print(gp)
+
+
+###################################################
+### code chunk number 66: features_1
 ###################################################
 head(features(myGene))
 
 
 ###################################################
-### code chunk number 64: features_2
+### code chunk number 67: features_2
 ###################################################
 genetrack<-makeGeneRegionTrack(myGene)
 plotTracks(genetrack)
 
 
 ###################################################
-### code chunk number 65: features_3
+### code chunk number 68: features_3
 ###################################################
 trackList<-list()
 myStart<-min(features(myGene)$start)
@@ -537,17 +561,17 @@ trackList<-c(trackList,ideoTrack)
 
 axtrack<-GenomeAxisTrack()
 trackList<-c(trackList,axtrack)
- 
+
 genetrack<-makeGeneRegionTrack(myGene)
 genetrack
- 
+
 trackList<-c(trackList,genetrack)
- 
+
 biomTrack<-BiomartGeneRegionTrack(genome=genome,chromosome=as.character(myChr),
 		start=myStart,end=myEnd,name="ENSEMBL",showId=T)
- 
+
 trackList<-c(trackList,biomTrack)
- 
+
 conservation <- UcscTrack(genome = genome, chromosome = myChr,
 		track = "Conservation", table = "phyloP100wayAll",
 		from = myStart-2000, to = myEnd+2000, trackType = "DataTrack",
@@ -557,20 +581,20 @@ conservation <- UcscTrack(genome = genome, chromosome = myChr,
 		name = "Conservation")
 
 trackList<-c(trackList,conservation)
- 
+
 plotTracks(trackList,from=myStart-2000,to=myEnd+2000)
 
 
 
 ###################################################
-### code chunk number 66: sig_mat_1
+### code chunk number 69: sig_mat_1
 ###################################################
 mySigMat<-sigMatrix(cuff,level='genes',alpha=0.05)
 
 
 
 ###################################################
-### code chunk number 67: sig_mat_plot_1
+### code chunk number 70: sig_mat_plot_1
 ###################################################
 mySigMat<-sigMatrix(cuff,level='genes',alpha=0.05)
 
@@ -578,7 +602,7 @@ print(mySigMat)
 
 
 ###################################################
-### code chunk number 68: get_sig_1
+### code chunk number 71: get_sig_1
 ###################################################
 mySigGeneIds<-getSig(cuff,alpha=0.05,level='genes')
 head(mySigGeneIds)
@@ -586,7 +610,7 @@ length(mySigGeneIds)
 
 
 ###################################################
-### code chunk number 69: get_sig_2
+### code chunk number 72: get_sig_2
 ###################################################
 hESC_vs_iPS.sigIsoformIds<-getSig(cuff,x='hESC',y='iPS',alpha=0.05,level='isoforms')
 head(hESC_vs_iPS.sigIsoformIds)
@@ -594,7 +618,7 @@ length(hESC_vs_iPS.sigIsoformIds)
 
 
 ###################################################
-### code chunk number 70: get_sig_3
+### code chunk number 73: get_sig_3
 ###################################################
 mySigGenes<-getGenes(cuff,mySigGeneIds)
 mySigGenes
@@ -602,21 +626,21 @@ mySigGenes
 
 
 ###################################################
-### code chunk number 71: get_sig_4
+### code chunk number 74: get_sig_4
 ###################################################
 mySigTable<-getSigTable(cuff,alpha=0.01,level='genes')
 head(mySigTable,20)
 
 
 ###################################################
-### code chunk number 72: dist_heat_1
+### code chunk number 75: dist_heat_1
 ###################################################
 myDistHeat<-csDistHeat(genes(cuff))
 
 
 
 ###################################################
-### code chunk number 73: dist_heat_plot_1
+### code chunk number 76: dist_heat_plot_1
 ###################################################
 myDistHeat<-csDistHeat(genes(cuff))
 
@@ -624,14 +648,14 @@ print(myDistHeat)
 
 
 ###################################################
-### code chunk number 74: dist_heat_2
+### code chunk number 77: dist_heat_2
 ###################################################
 myRepDistHeat<-csDistHeat(genes(cuff),replicates=T)
 
 
 
 ###################################################
-### code chunk number 75: dist_heat_plot_2
+### code chunk number 78: dist_heat_plot_2
 ###################################################
 myRepDistHeat<-csDistHeat(genes(cuff),replicates=T)
 
@@ -639,7 +663,7 @@ print(myRepDistHeat)
 
 
 ###################################################
-### code chunk number 76: dim_reduction_1
+### code chunk number 79: dim_reduction_1
 ###################################################
 genes.PCA<-PCAplot(genes(cuff),"PC1","PC2")
 genes.MDS<-MDSplot(genes(cuff))
@@ -649,7 +673,7 @@ genes.MDS.rep<-MDSplot(genes(cuff),replicates=T)
 
 
 ###################################################
-### code chunk number 77: gene_PCA
+### code chunk number 80: gene_PCA
 ###################################################
 genes.PCA<-PCAplot(genes(cuff),"PC1","PC2")
 genes.MDS<-MDSplot(genes(cuff))
@@ -660,28 +684,28 @@ genes.MDS.rep<-MDSplot(genes(cuff),replicates=T)
 
 
 ###################################################
-### code chunk number 78: gene_MDS
+### code chunk number 81: gene_MDS
 ###################################################
 
 	print(genes.MDS)
 
 
 ###################################################
-### code chunk number 79: gene_PCA_rep
+### code chunk number 82: gene_PCA_rep
 ###################################################
 
 	print(genes.PCA.rep)
 
 
 ###################################################
-### code chunk number 80: gene_MDS_rep
+### code chunk number 83: gene_MDS_rep
 ###################################################
 
 	print(genes.MDS.rep)
 
 
 ###################################################
-### code chunk number 81: geneset_cluster_1
+### code chunk number 84: geneset_cluster_1
 ###################################################
 ic<-csCluster(myGenes,k=4)
 head(ic$cluster)
@@ -690,27 +714,27 @@ icp
 
 
 ###################################################
-### code chunk number 82: geneset_plots_cluster
+### code chunk number 85: geneset_plots_cluster
 ###################################################
 print(icp)
 
 
 ###################################################
-### code chunk number 83: specificity_1
+### code chunk number 86: specificity_1
 ###################################################
 myGenes.spec<-csSpecificity(myGenes)
 head(myGenes.spec)
 
 
 ###################################################
-### code chunk number 84: similar_1
+### code chunk number 87: similar_1
 ###################################################
 mySimilar<-findSimilar(cuff,"PINK1",n=20)
 mySimilar.expression<-expressionPlot(mySimilar,logMode=T,showErrorbars=F)
 
 
 ###################################################
-### code chunk number 85: similar_plots_1
+### code chunk number 88: similar_plots_1
 ###################################################
 mySimilar<-findSimilar(cuff,"PINK1",n=20)
 mySimilar.expression<-expressionPlot(mySimilar,logMode=T,showErrorbars=F)
@@ -718,7 +742,7 @@ print(mySimilar.expression)
 
 
 ###################################################
-### code chunk number 86: similar_2
+### code chunk number 89: similar_2
 ###################################################
 myProfile<-c(500,0,400)
 mySimilar2<-findSimilar(cuff,myProfile,n=10)
@@ -726,7 +750,7 @@ mySimilar2.expression<-expressionPlot(mySimilar2,logMode=T,showErrorbars=F)
 
 
 ###################################################
-### code chunk number 87: similar_plots_2
+### code chunk number 90: similar_plots_2
 ###################################################
 myProfile<-c(500,0,400)
 mySimilar2<-findSimilar(cuff,myProfile,n=10)
@@ -735,13 +759,13 @@ print(mySimilar2.expression)
 
 
 ###################################################
-### code chunk number 88: close_connection
+### code chunk number 91: close_connection
 ###################################################
-end<-sqliteCloseConnection(cuff@DB)
+end<-dbDisconnect(cuff@DB)
 
 
 ###################################################
-### code chunk number 89: session
+### code chunk number 92: session
 ###################################################
 sessionInfo()
 
